@@ -3,7 +3,8 @@ use super::*;
 
 #[derive(Debug, Default)]
 pub struct ClientBuilder {
-    gzip: bool,
+    pub(super) gzip: bool,
+    pub(super) cors_proxy: Option<String>,
 }
 
 impl ClientBuilder {
@@ -16,6 +17,11 @@ impl ClientBuilder {
         self
     }
 
+    pub fn cors_proxy(mut self, domain: &str) -> Self {
+        self.cors_proxy = Some(domain.to_string());
+        self
+    }
+
     pub fn build(self) -> Result<Client, Error> {
         Ok(Client { builder: self })
     }
